==> apache-shenyu-incubating-2.4.2-src.zip: apache-shenyu-incubating-2.4.2-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/config/ConsulServerConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.config;

import org.apache.shenyu.register.common.config.ShenyuRegisterCenterConfig;
import org.apache.shenyu.register.server.consul.ShenyuConsulConfigWatch;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConditionalOnProperty(prefix = "shenyu.register", name = "registerType", havingValue = "consul")
public class ConsulServerConfiguration {
    
    /**
     * Register shenyuConsulConfigWatch for ConsulServerRegisterRepository to monitor metadata.
     *
     * @param config the shenyu register center config
     * @param publisher the application event publisher
     * @return the consul config watch
     */
    @Bean
    public ShenyuConsulConfigWatch shenyuConsulConfigWatch(final ShenyuRegisterCenterConfig config, final ApplicationEventPublisher publisher) {
        return new ShenyuConsulConfigWatch(config, publisher);
    }
}

==> apache-shenyu-incubating-2.4.3-src.zip: apache-shenyu-incubating-2.4.3-src/shenyu-admin/src/main/java/org/apache/shenyu/admin/config/ConsulServerConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shenyu.admin.config;

import com.ecwid.consul.v1.ConsulClient;
import org.apache.shenyu.register.common.config.ShenyuRegisterCenterConfig;
import org.apache.shenyu.register.server.consul.ShenyuConsulConfigWatch;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.ApplicationEventPublisher;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
@ConditionalOnProperty(prefix = "shenyu.register", name = "registerType", havingValue = "consul")
public class ConsulServerConfiguration {
    /**
     * Register consul client, distinguished from sync consul client.

     * @param config the shenyu register center config
     * @return the consulClient
     */
    @Bean(name = "registerConsulClient")
    public ConsulClient consulClient(final ShenyuRegisterCenterConfig config) {
        return new ConsulClient(config.getServerLists());
    }

    /**
     * Register shenyuConsulConfigWatch for ConsulServerRegisterRepository to monitor metadata.
     *
     * @param config the shenyu register center config
     * @param publisher the application event publisher
     * @return the consul config watch
     */
    @Bean
    public ShenyuConsulConfigWatch shenyuConsulConfigWatch(final ShenyuRegisterCenterConfig config, final ApplicationEventPublisher publisher) {
        return new ShenyuConsulConfigWatch(config, publisher);
    }
}
